#
# spec file for package ghc-HTTP
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name HTTP
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        4000.4.1
Release:        3.10
Summary:        A library for client-side HTTP
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/4.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-prof
BuildRequires:  ghc-network-uri-devel
BuildRequires:  ghc-network-uri-prof
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-parsec-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-httpd-shed-devel
BuildRequires:  ghc-httpd-shed-prof
BuildRequires:  ghc-pureMD5-devel
BuildRequires:  ghc-pureMD5-prof
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-split-prof
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-hunit-prof
BuildRequires:  ghc-test-framework-prof
%endif

%description
The HTTP package supports client-side web programming in Haskell. It lets you
set up HTTP connections, transmitting requests and processing the responses
coming back, all from within the comforts of Haskell. It's dependent on the
network package to operate, but other than that, the implementation is all
written in Haskell.

A basic API for issuing single HTTP requests + receiving responses is provided.
On top of that, a session-level abstraction is also on offer (the
'BrowserAction' monad); it taking care of handling the management of persistent
connections, proxies, state (cookies) and authentication credentials required
to handle multi-step interactions with a web server.

The representation of the bytes flowing across is extensible via the use of a
type class, letting you pick the representation of requests and responses that
best fits your use. Some pre-packaged, common instances are provided for you
('ByteString', 'String').

Here's an example use:

> > do > rsp <- Network.HTTP.simpleHTTP (getRequest "http://www.haskell.org/")
> -- fetch document and return it (as a 'String'.) > fmap (take 100)
(getResponseBody rsp) > > do > (_, rsp) > <- Network.Browser.browse $ do >
setAllowRedirects True -- handle HTTP redirects > request $ getRequest
"http://www.haskell.org/" > return (take 100 (rspBody rsp))

__Note:__ This package does not support HTTPS connections. If you need HTTPS,
take a look at the following packages:

* <http://hackage.haskell.org/package/http-streams http-streams>

* <http://hackage.haskell.org/package/http-client http-client> (in combination
with <http://hackage.haskell.org/package/http-client-tls http-client-tls>)

* <http://hackage.haskell.org/package/req req>

* <http://hackage.haskell.org/package/wreq wreq>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Mon Apr 15 2024 Peter Simons <psimons@suse.com>
- Update HTTP to version 4000.4.1 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Oct  7 2023 Peter Simons <psimons@suse.com>
- Update HTTP to version 4000.4.1 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Thu Mar 16 2023 Peter Simons <psimons@suse.com>
- Update HTTP to version 4000.4.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Aug 14 2022 Peter Simons <psimons@suse.com>
- Update HTTP to version 4000.4.1 revision 1.
  Version 4000.4.0: release 2022-02-22
  * Restrict to GHC >=7.6 and associated cleanups (Andreas Abel)
  * Drop deprecated instance Error (Andreas Abel)
  * Preparation for mtl-2.3 (Andreas Abel)
  * General tidying (Andreas Abel)
  * Support GHC 9.2 (Bodigrim)
* Tue Oct 12 2021 psimons@suse.com
- Update HTTP to version 4000.3.16 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Mar 22 2021 psimons@suse.com
- Update HTTP to version 4000.3.16.
  Version 4000.3.16: release 2021-03-20
  * Support GHC-9.0 (Oleg Genrus)
  * Various dependency bumps (multiple people)
  * Try all addresses returned by getAddrInfo (Fraser Tweedale)
  Version ?
* Tue Dec 22 2020 psimons@suse.com
- Update HTTP to version 4000.3.15 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Sun Sep 27 2020 psimons@suse.com
- Update HTTP to version 4000.3.15 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Sep 15 2020 psimons@suse.com
- Update HTTP to version 4000.3.15.
  Upstream has not updated the file "CHANGES" since the last
  release.
* Mon Aug 31 2020 psimons@suse.com
- Update HTTP to version 4000.3.14 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Thu May  7 2020 Peter Simons <psimons@suse.com>
- Update Cabal file to get more accurate dependency information.
* Fri Feb 28 2020 Peter Simons <psimons@suse.com>
- Update Cabal build information for more accurate dependencies.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Tue Jun 18 2019 psimons@suse.com
- Update HTTP to version 4000.3.14.
  Upstream has not updated the file "CHANGES" since the last
  release.
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Mon Mar 18 2019 psimons@suse.com
- Update HTTP to version 4000.3.13.
  Upstream has not updated the file "CHANGES" since the last
  release.
* Fri Oct 19 2018 Peter Simons <psimons@suse.com>
- Update Cabal build instructions to support ghc-8.6.1.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update HTTP to version 4000.3.12.
  Upstream has not updated the file "CHANGES" since the last
  release.
* Mon May 14 2018 psimons@suse.com
- Update HTTP to version 4000.3.11.
  Upstream does not provide a changelog.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon May 22 2017 psimons@suse.com
- Update to version 4000.3.7 with cabal2obs.
* Mon Mar 27 2017 psimons@suse.com
- Update to version 4000.3.6 with cabal2obs.
* Mon Jan 30 2017 psimons@suse.com
- Update to version 4000.3.5 revision 2 with cabal2obs.
* Sun Jan  8 2017 psimons@suse.com
- Update to version 4000.3.4 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 4000.3.3 revision 0 with cabal2obs.
* Thu Feb 11 2016 mimi.vx@gmail.com
- update to 4000.3.3
* Sun Jan 24 2016 mimi.vx@gmail.com
- update to 4000.3.2
  * If the URI contains "user:pass@" part, use it for Basic Authorization
  * Add a test harness.
  * Don't leak a socket when getHostAddr throws an exception.
  * Send cookies in request format, not response format.
  * Moved BrowserAction to be a StateT IO, with instances for
  Applicative, MonadIO, MonadState.
  * Add method to control size of connection pool.
  * Consider both host and port when reusing connections.
  * Handle response code 304 "not modified" properly.
  * Fix digest authentication by fixing md5 output string rep.
  * Make the default user agent string follow the package version.
  * Document lack of HTTPS support and fail when clients try
  to use it instead of silently falling back to HTTP.
  * Add helper to set the request type and body.
* Fri Jan  1 2016 mimi.vx@gmail.com
- update to 4000.2.23
* Mon Dec  7 2015 mimi.vx@gmail.com
- update to 4000.2.22
* Sun Nov 29 2015 mimi.vx@gmail.com
- update to 4000.2.21
* Sun Jun 28 2015 mimi.vx@gmail.com
- update to 4000.2.20
  * If the URI contains "user:pass@" part, use it for Basic Authorization
  * Add a test harness.
  * Don't leak a socket when getHostAddr throws an exception.
  * Send cookies in request format, not response format.
  * Moved BrowserAction to be a StateT IO, with instances for
  Applicative, MonadIO, MonadState.
  * Add method to control size of connection pool.
  * Consider both host and port when reusing connections.
  * Handle response code 304 "not modified" properly.
  * Fix digest authentication by fixing md5 output string rep.
  * Make the default user agent string follow the package version.
  * Document lack of HTTPS support and fail when clients try
  to use it instead of silently falling back to HTTP.
  * Add helper to set the request type and body.
* Sat Apr 11 2015 mimi.vx@gmail.com
- update to 4000.2.19
  * no upstream changelog
* Tue Sep  9 2014 peter.trommler@ohm-hochschule.de
- update to 4000.2.10
  * no changelog
  * for Haskell Platform 2014.2.0.0
* Mon Sep  1 2014 peter.trommler@ohm-hochschule.de
- regenerate spec file with cabal-rpm 0.8.6
  * require exact version of ghc-compiler
* Fri Aug 22 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Tue May  7 2013 peter.trommler@ohm-hochschule.de
- update to 4000.2.8 from upstream
  * fix resource leaks in getHostAddr
  * correct cookie format
- part of Haskell Platform 2013.2
- more transparent packaging (fewer macros)
* Tue Jan  8 2013 peter.trommler@ohm-hochschule.de
- expand macro in name tag to help source validator
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service localonly for Factory submission
* Mon Oct  1 2012 peter.trommler@ohm-hochschule.de
- update to 4000.2.5 from upstream
- required by Haskell Platform 2012.4.0.0
* Sun Jun  3 2012 peter.trommler@ohm-hochschule.de
- update to 4000.2.3 from upstream
  * support mtl 2.1
- required by Haskell Platform 2012.2.0.0
* Wed Dec 28 2011 peter.trommler@ohm-hochschule.de
- Adjust version number for platform 2011.4
* Thu Dec  8 2011 peter.trommler@ohm-hochschule.de
- Fixed arches.
* Thu Dec  8 2011 peter.trommler@ohm-hochschule.de
- Initial packaging.
